@@ -1,18 +1,19 @@
-see.chicdf.tck<-function () 
+see.chicdf.tck<-function ()
 {
 
  # old.par <- par(no.readonly = TRUE)
-  
-    if (!exists("slider.env")) 
-    slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
+
+    if (!exists("slider.env"))
+    slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check
     nu <- 5
     assign("nu", tclVar(nu), envir = slider.env)
     xmin <- 0
     assign("xmin", tclVar(xmin), envir = slider.env)
     xmax <- 20
     assign("xmax", tclVar(xmax), envir = slider.env)
-        
-    dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1.75,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
+
+    dev.new(height=4,width=8,noRStudioGD = TRUE)
+    par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1.75,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
     norm.refresh <- function(...) {
         nu <- as.numeric(evalq(tclvalue(nu), envir = slider.env))
         xmin <- as.numeric(evalq(tclvalue(xmin), envir = slider.env))
@@ -33,8 +34,8 @@ see.chicdf.tck<-function ()
     tkwm.geometry(m, "+0+0")
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = '\u03bd',font=c("Helvetica","9","italic"),width = "20"), side = "right")
-    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 1, 
-        to = 30, orient = "horiz", resolution = 1, showvalue = TRUE), 
+    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 1,
+        to = 30, orient = "horiz", resolution = 1, showvalue = TRUE),
         side = "left")
     assign("sc", sc, envir = slider.env)
     evalq(tkconfigure(sc, variable = nu), envir = slider.env)
@@ -47,26 +48,28 @@ see.chicdf.tck<-function ()
     tkpack(e <- tkentry(fr, width = 8), side = "left")
     assign("e", e, envir = slider.env)
     evalq(tkconfigure(e, textvariable = xmax), envir = slider.env)
-    tkpack(tkbutton(m, text = "Refresh", command = norm.refresh), 
+    tkpack(tkbutton(m, text = "Refresh", command = norm.refresh),
         side = "left")
-    tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
+    tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)),
         side = "right")
 #    on.exit(par(old.par))
         }
 
 
-see.chi.tck<-function () 
+see.chi.tck<-function ()
 {
 
-    if (!exists("slider.env")) 
-    slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
+    if (!exists("slider.env"))
+    slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check
     nu <- 5
     assign("nu", tclVar(nu), envir = slider.env)
     xmin <- 0
     assign("xmin", tclVar(xmin), envir = slider.env)
     xmax <- 20
     assign("xmax", tclVar(xmax), envir = slider.env)
-           
+
+    if(names(dev.cur()) == "RStudioGD") dev.new(noRStudioGD = TRUE)
+
     norm.refresh <- function(...) {
         nu <- as.numeric(evalq(tclvalue(nu), envir = slider.env))
         xmin <- as.numeric(evalq(tclvalue(xmin), envir = slider.env))
@@ -86,8 +89,8 @@ see.chi.tck<-function ()
     tkwm.geometry(m, "+0+0")
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = '\u03bd',font=c("Helvetica","9","italic"),width = "20"), side = "right")
-    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 1, 
-        to = 30, orient = "horiz", resolution = 1, showvalue = TRUE), 
+    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 1,
+        to = 30, orient = "horiz", resolution = 1, showvalue = TRUE),
         side = "left")
     assign("sc", sc, envir = slider.env)
     evalq(tkconfigure(sc, variable = nu), envir = slider.env)
@@ -99,9 +102,9 @@ see.chi.tck<-function ()
     tkpack(tklabel(fr, text = "Xmax:", width = 6), side = "left")
     tkpack(e <- tkentry(fr, width = 8), side = "left")
     assign("e", e, envir = slider.env)
-    evalq(tkconfigure(e, textvariable = xmax), envir = slider.env) 
-    tkpack(tkbutton(m, text = "Refresh", command = norm.refresh), 
+    evalq(tkconfigure(e, textvariable = xmax), envir = slider.env)
+    tkpack(tkbutton(m, text = "Refresh", command = norm.refresh),
         side = "left")
-    tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
+    tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)),
         side = "right")
-}
\ No newline at end of file
+}
