@@ -1,8 +1,8 @@
-see.exp.tck<-function () 
+see.exp.tck<-function ()
 {
 
-    if (!exists("slider.env")) 
-        slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
+    if (!exists("slider.env"))
+    slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check
     theta <- 1
     beta <- 0
     assign("theta", tclVar(theta), envir = slider.env)
@@ -10,8 +10,10 @@ see.exp.tck<-function ()
     assign("xmin", tclVar(xmin), envir = slider.env)
     xmax <- 6
     assign("xmax", tclVar(xmax), envir = slider.env)
-           
-   norm.refresh <- function(...) {
+
+    if(names(dev.cur()) == "RStudioGD") dev.new(noRStudioGD = TRUE)
+
+    norm.refresh <- function(...) {
         dev.hold()
         theta <- as.numeric(evalq(tclvalue(theta), envir = slider.env))
         xmin <- as.numeric(evalq(tclvalue(xmin), envir = slider.env))
@@ -20,9 +22,9 @@ see.exp.tck<-function ()
         yy <- dexp(xx, theta)
         plot(xx, yy, type = "l", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(f),"(",italic(x),")", sep = "")))
         mtext(bquote(paste(italic(X), " ~ ", italic(EXP), "(", .(theta), ")", sep = "")), line = 1, side = 3)
-        dev.flush()            
+        dev.flush()
         }
-                    
+
     tclServiceMode(TRUE)
     m <- tktoplevel()
     tkwm.title(m, "EXP(\u03b8)")
@@ -30,13 +32,13 @@ see.exp.tck<-function ()
     tkwm.geometry(m, "+0+0")
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = '\u03b8', font=c("Helvetica","9","italic"), width = "20"), side = "right")
-    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0, 
-        to = 2.9, orient = "horiz", resolution = 0.1, showvalue = TRUE), 
+    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0,
+        to = 2.9, orient = "horiz", resolution = 0.1, showvalue = TRUE),
         side = "left")
     assign("sc", sc, envir = slider.env)
     evalq(tkconfigure(sc, variable = theta), envir = slider.env)
-      
-    
+
+
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = "Xmin:", width = 6), side = "left")
     tkpack(e <- tkentry(fr, width = 8), side = "left")
@@ -47,23 +49,24 @@ see.exp.tck<-function ()
     assign("e", e, envir = slider.env)
     evalq(tkconfigure(e, textvariable = xmax), envir = slider.env)
     tkpack(fr <- tkframe(m), side = "top")
-    tkpack(tkbutton(m, text = "Refresh", command = norm.refresh), 
+    tkpack(tkbutton(m, text = "Refresh", command = norm.refresh),
         side = "left")
-    tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
+    tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)),
         side = "right")
 }
 
-see.expcdf.tck<-function (){ 
+see.expcdf.tck<-function (){
 #  old.par <- par(no.readonly = TRUE)
-    if (!exists("slider.env")) 
-        slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
+    if (!exists("slider.env"))
+        slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check
     theta <- 1
     assign("theta", tclVar(theta), envir = slider.env)
     xmin <- 0
     assign("xmin", tclVar(xmin), envir = slider.env)
     xmax <- 6
     assign("xmax", tclVar(xmax), envir = slider.env)
-   dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1.5,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))        
+   dev.new(height=4,width=8,noRStudioGD = TRUE)
+   par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1.5,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
    norm.refresh <- function(...) {
         dev.hold()
         theta <- as.numeric(evalq(tclvalue(theta), envir = slider.env))
@@ -76,8 +79,8 @@ see.expcdf.tck<-function (){
         plot(xx, y1, type = "l", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(F),"(",italic(x),")", sep = "")))
         mtext(bquote(paste(italic(X), " ~ ", italic(EXP), "(", .(theta), ")", sep = "")), outer = TRUE, side = 3, cex = .9)
         dev.flush()
- }  
-    
+ }
+
     tclServiceMode(TRUE)
     m <- tktoplevel()
     tkwm.title(m, "EXP(\u03b8)")
@@ -85,13 +88,13 @@ see.expcdf.tck<-function (){
     tkwm.geometry(m, "+0+0")
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = '\u03b8', font=c("Helvetica","9","italic"), width = "20"), side = "right")
-    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0, 
-        to = 2.9, orient = "horiz", resolution = 0.1, showvalue = TRUE), 
+    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0,
+        to = 2.9, orient = "horiz", resolution = 0.1, showvalue = TRUE),
         side = "left")
     assign("sc", sc, envir = slider.env)
     evalq(tkconfigure(sc, variable = theta), envir = slider.env)
-      
-    
+
+
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = "Xmin:", width = 6), side = "left")
     tkpack(e <- tkentry(fr, width = 8), side = "left")
@@ -102,10 +105,10 @@ see.expcdf.tck<-function (){
     assign("e", e, envir = slider.env)
     evalq(tkconfigure(e, textvariable = xmax), envir = slider.env)
     tkpack(fr <- tkframe(m), side = "top")
-    tkpack(tkbutton(m, text = "Refresh", command = norm.refresh), 
+    tkpack(tkbutton(m, text = "Refresh", command = norm.refresh),
         side = "left")
-    tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
+    tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)),
         side = "right")
-    
+
  #   on.exit(par(old.par))
-  }
\ No newline at end of file
+  }
