@@ -1,8 +1,8 @@
-see.gam.tck<-function () 
+see.gam.tck<-function ()
 {
 
-    if (!exists("slider.env")) 
-    slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
+    if (!exists("slider.env"))
+    slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check
     theta <- 1
     kappa<-1
     assign("theta", tclVar(theta), envir = slider.env)
@@ -11,7 +11,8 @@ see.gam.tck<-function ()
     assign("xmin", tclVar(xmin), envir = slider.env)
     xmax <- 30
     assign("xmax", tclVar(xmax), envir = slider.env)
-           
+
+    if(names(dev.cur()) == "RStudioGD") dev.new(noRStudioGD = TRUE)
    norm.refresh <- function(...) {
         theta <- as.numeric(evalq(tclvalue(theta), envir = slider.env))
         kappa <- as.numeric(evalq(tclvalue(kappa), envir = slider.env))
@@ -28,28 +29,28 @@ see.gam.tck<-function ()
     tkwm.title(m, "GAM(\u03ba, \u03b8)")
     tkpack(tklabel(m,text="      Visualizing the Gamma Distribution      "))
     tkwm.geometry(m, "+0+0")
-    
-                             
+
+
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = '\u03ba',font=c("Helvetica","9","italic"), width = "20"), side = "right")
-    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.1, 
-        to = 15, orient = "horiz", resolution = 0.1, showvalue = TRUE), 
+    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.1,
+        to = 15, orient = "horiz", resolution = 0.1, showvalue = TRUE),
         side = "left")
     assign("sc", sc, envir = slider.env)
     evalq(tkconfigure(sc, variable = kappa), envir = slider.env)
-    
-    
+
+
     tkpack(fr <- tkframe(m), side = "top")
-    tkpack(tklabel(fr, text = '\u03b8',font=c("Helvetica","9","italic"), width = "20"), 
+    tkpack(tklabel(fr, text = '\u03b8',font=c("Helvetica","9","italic"), width = "20"),
         side = "right")
-    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.1, 
-        to = 5, orient = "horiz", resolution = 0.1, showvalue = TRUE), 
+    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.1,
+        to = 5, orient = "horiz", resolution = 0.1, showvalue = TRUE),
         side = "left")
     assign("sc", sc, envir = slider.env)
     evalq(tkconfigure(sc, variable = theta), envir = slider.env)
-    
-    
-    
+
+
+
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = "Xmin:", width = 6), side = "left")
     tkpack(e <- tkentry(fr, width = 8), side = "left")
@@ -59,18 +60,18 @@ see.gam.tck<-function ()
     tkpack(e <- tkentry(fr, width = 8), side = "left")
     assign("e", e, envir = slider.env)
     evalq(tkconfigure(e, textvariable = xmax), envir = slider.env)
-    tkpack(tkbutton(m, text = "Refresh", command = norm.refresh), 
+    tkpack(tkbutton(m, text = "Refresh", command = norm.refresh),
         side = "left")
-    tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
+    tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)),
         side = "right")
 }
 
 
 
-see.gamcdf.tck<-function (){ 
+see.gamcdf.tck<-function (){
 #  old.par <- par(no.readonly = TRUE)
-    if (!exists("slider.env")) 
-    slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
+    if (!exists("slider.env"))
+    slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check
     theta <- 1
     kappa<-1
     assign("theta", tclVar(theta), envir = slider.env)
@@ -79,8 +80,9 @@ see.gamcdf.tck<-function (){
     assign("xmin", tclVar(xmin), envir = slider.env)
     xmax <- 30
     assign("xmax", tclVar(xmax), envir = slider.env)
-           
-   dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1.5,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
+
+   dev.new(height=4,width=8,noRStudioGD = TRUE)
+   par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1.5,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
    norm.refresh <- function(...) {
         theta <- as.numeric(evalq(tclvalue(theta), envir = slider.env))
         kappa <- as.numeric(evalq(tclvalue(kappa), envir = slider.env))
@@ -93,33 +95,33 @@ see.gamcdf.tck<-function (){
         plot(xx, yy, type = "l", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(f),"(",italic(x),")", sep = "")))
         plot(xx, y1, type = "l", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(F),"(",italic(x),")", sep = "")))
         mtext(bquote(paste(italic(X), " ~ ", italic(GAM), "(", .(kappa), ", ", .(theta),")", sep = "")), outer = TRUE, side = 3, cex = .9)
-        dev.flush()          
+        dev.flush()
                     }
     tclServiceMode(TRUE)
     m <- tktoplevel()
     tkwm.title(m, "GAM(\u03ba, \u03b8)")
     tkpack(tklabel(m,text="      Visualizing the Gamma Distribution      "))
     tkwm.geometry(m, "+0+0")
-    
+
      tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = '\u03ba',font=c("Helvetica","9","italic"), width = "20"), side = "right")
-    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.1, 
-        to = 15, orient = "horiz", resolution = 0.1, showvalue = TRUE), 
+    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.1,
+        to = 15, orient = "horiz", resolution = 0.1, showvalue = TRUE),
         side = "left")
     assign("sc", sc, envir = slider.env)
     evalq(tkconfigure(sc, variable = kappa), envir = slider.env)
-    
+
     tkpack(fr <- tkframe(m), side = "top")
-    tkpack(tklabel(fr, text = '\u03b8',font=c("Helvetica","9","italic"), width = "20"), 
+    tkpack(tklabel(fr, text = '\u03b8',font=c("Helvetica","9","italic"), width = "20"),
         side = "right")
-    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.1, 
-        to = 5, orient = "horiz", resolution = 0.1, showvalue = TRUE), 
+    tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.1,
+        to = 5, orient = "horiz", resolution = 0.1, showvalue = TRUE),
         side = "left")
     assign("sc", sc, envir = slider.env)
     evalq(tkconfigure(sc, variable = theta), envir = slider.env)
-    
-   
-    
+
+
+
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = "Xmin:", width = 6), side = "left")
     tkpack(e <- tkentry(fr, width = 8), side = "left")
@@ -129,10 +131,9 @@ see.gamcdf.tck<-function (){
     tkpack(e <- tkentry(fr, width = 8), side = "left")
     assign("e", e, envir = slider.env)
     evalq(tkconfigure(e, textvariable = xmax), envir = slider.env)
-    tkpack(tkbutton(m, text = "Refresh", command = norm.refresh), 
+    tkpack(tkbutton(m, text = "Refresh", command = norm.refresh),
         side = "left")
-    tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
+    tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)),
         side = "right")
  #   on.exit(par(old.par))
-  }  
-                            
\ No newline at end of file
+  }
